import 'package:example/counter/counter.dart';
import 'package:example/l10n/l10n.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:flutter_mobx/flutter_mobx.dart';
import 'package:healthrian_ble_support_for_wearecg12/healthrian_ble_support_for_wearecg12.dart';
import 'package:healthrian_visualization_support/healthrian_visualization_support.dart';

class CounterPage extends StatelessWidget {
  const CounterPage({super.key});

  @override
  Widget build(BuildContext context) {
    return BlocProvider(
      create: (_) => CounterCubit(),
      child: const CounterView(),
    );
  }
}

class CounterView extends StatelessWidget {
  const CounterView({super.key});

  @override
  Widget build(BuildContext context) {
    final l10n = context.l10n;
    return Scaffold(
      // appBar: AppBar(title: Text(l10n.counterAppBarTitle)),
      body: ListView(
        children: [
          Observer(
            key: UniqueKey(),
            builder: (context) {
              return StreamBuilder(
                stream: BLEManager().streams.heartRateStream,
                builder: (context, snapshot) {
                  if (!snapshot.hasData) return const Text('No Stream');
                  return Text(snapshot.data.toString());
                },
              );
            },
          ),
          // Observer(
          //   key: UniqueKey(),
          //   builder: (context) {
          //     return StreamBuilder(
          //       stream: BLEManager().streams.bufferedPlotRTStreamEcg,
          //       builder: (context, snapshot) {
          //         if (!snapshot.hasData) return const Text('No Stream');
          //         return Column(
          //           children: [
          //             for (final channel in snapshot.data!)
          //               SizedBox(
          //                 width: MediaQuery.of(context).size.width,
          //                 height: 50,
          //                 child: Channel(
          //                   ecgSequence: channel,
          //                   measureTime: 5,
          //                 ),
          //               ),
          //           ],
          //         );
          //       },
          //     );
          //   },
          // )
        ],
      ),
      floatingActionButton: Column(
        mainAxisAlignment: MainAxisAlignment.end,
        crossAxisAlignment: CrossAxisAlignment.end,
        children: [
          IconButton(
            onPressed: () {
              BLEManager().connectDevice();
            },
            icon: const Icon(Icons.bluetooth),
          ),
          IconButton(
            onPressed: () {
              BLEManager().disconnectDevice();
            },
            icon: const Icon(Icons.bluetooth_disabled),
          ),
          IconButton(
            onPressed: () async {
              await BLEManager().registerCharacteristics();
              await BLEManager().startMeasurementEcg();
            },
            icon: const Icon(Icons.play_arrow),
          ),
          IconButton(
            onPressed: () async {
              await BLEManager().stopMeasurementEcg();
              await BLEManager().initializeStreams();
            },
            icon: const Icon(Icons.stop),
          ),
          FloatingActionButton(
            onPressed: () => context.read<CounterCubit>().increment(),
            child: const Icon(Icons.add),
          ),
          const SizedBox(height: 8),
          FloatingActionButton(
            onPressed: () => context.read<CounterCubit>().decrement(),
            child: const Icon(Icons.remove),
          ),
        ],
      ),
    );
  }
}

class CounterText extends StatelessWidget {
  const CounterText({super.key});

  @override
  Widget build(BuildContext context) {
    final theme = Theme.of(context);
    final count = context.select((CounterCubit cubit) => cubit.state);
    return Text('$count', style: theme.textTheme.displayLarge);
  }
}
